@@ -577,20 +577,20 @@ function(object, digits = 12, ...)
 ## e.g. trunc(times("12:13:14"), 1/(24*60))         # same
 ## e.g. trunc(times("12:13:14"), "00:01:30") # truncate to 90 seconds
 trunc.times <-
-function (x, units = "days")
+function (x, units = "days", eps = 1e-10)
 {
-   if (is.character(units)) {
-      idx <- pmatch(units, c("days", "hours", "minutes", "seconds"))
-      if (!is.na(idx)) {
-         values <- c(1, as.numeric(times(c("01:00:00","00:01:00","00:00:01"))))
-	 units <- values[idx]
-      }
+    if(is.character(units)) {
+        idx <- pmatch(units, c("days", "hours", "minutes", "seconds"))
+        if(!is.na(idx)) {
+            values <- c(1, as.numeric(times(c("01:00:00","00:01:00","00:00:01"))))
+            units <- values[idx]
+        }
     } 
-    if (!inherits(units, "times")) { 
-      units <- try(times(units))
-      if (inherits(units, "try-error")) 
-         stop("cannot coerce units to class: times")
+    if(!inherits(units, "times")) { 
+        units <- try(times(units))
+        if(inherits(units, "try-error")) 
+            stop("cannot coerce units to class: times")
     }
     units <- as.numeric(units)
-    times(units * trunc(as.numeric(x) / units))
+    times(units * trunc((as.numeric(x) + eps) / units))
 }
